@@ -1,11 +1,11 @@
 import pytest
 from pytest import approx
 
-from numerous import EquationBase, Equation
 from numerous.engine.model import Model
 from numerous.engine.simulation import Simulation
 from numerous.engine.simulation.solvers.base_solver import solver_types
 from numerous.engine.system import Subsystem, Item
+from numerous.multiphysics import EquationBase, Equation
 import numpy as np
 
 
@@ -36,11 +36,6 @@ def simple_item(test_eq1):
 
     return T1('test_item')
 
-@pytest.fixture(autouse=True)
-def run_before_and_after_tests():
-    import shutil
-    shutil.rmtree('./tmp', ignore_errors=True)
-    yield
 
 
 @pytest.fixture
