@@ -1,14 +1,8 @@
 import pytest
 
-from numerous.engine.variables import _VariableFactory, OverloadAction, VariableType, Variable
-from numerous import VariableDescription
+from numerous.engine.variables import _VariableFactory, VariableType, VariableDescription
 from tests.test_equations import *
 
-@pytest.fixture(autouse=True)
-def run_before_and_after_tests():
-    import shutil
-    shutil.rmtree('./tmp', ignore_errors=True)
-    yield
 
 
 @pytest.fixture
